@@ -145,6 +145,7 @@ EXTENSIONS = {
     'pyz': {'binary', 'pyz'},
     'pyzw': {'binary', 'pyz'},
     'r': {'text', 'r'},
+    'rake': {'text', 'ruby'},
     'rb': {'text', 'ruby'},
     'rs': {'text', 'rust'},
     'rst': {'text', 'rst'},
@@ -230,6 +231,8 @@ NAMES = {
     '.bashrc': EXTENSIONS['bash'],
     '.bowerrc': EXTENSIONS['json'] | {'bowerrc'},
     '.browserslistrc': {'text', 'browserslistrc'},
+    '.clang-format': EXTENSIONS['yaml'],
+    '.clang-tidy': EXTENSIONS['yaml'],
     '.codespellrc': EXTENSIONS['ini'] | {'codespellrc'},
     '.coveragerc': EXTENSIONS['ini'] | {'coveragerc'},
     '.cshrc': EXTENSIONS['csh'],
