@@ -3,9 +3,14 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 INTERPRETERS = {
+    'ash': {'shell', 'ash'},
+    'awk': {'awk'},
     'bash': {'shell', 'bash'},
+    'bats': {'shell', 'bash', 'bats'},
     'csh': {'shell', 'csh'},
     'dash': {'shell', 'dash'},
+    'expect': {'expect'},
+    'ksh': {'shell', 'ksh'},
     'node': {'javascript'},
     'nodejs': {'javascript'},
     'perl': {'perl'},
